--
-- DeutzIntrac
-- Specialization for Deutz Intrac
--
-- @author  farmer joe/John Deere 6930/Face
-- @date  29/12/09
--

Vehicle.registerJointType("attachableBucket");

DeutzIntrac = {};

function DeutzIntrac.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function DeutzIntrac:load(xmlFile)

	self.updateInterval = 0;

	self.rearCoupling = {};
	self.rearCoupling.node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rearCoupling#index"));
	self.rearCoupling.trailerNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rearCoupling#trailerIndex"));
	self.rearCoupling.trailerLowNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.rearCoupling#trailerLowIndex"));

	-- Defines attributes of drivingShaft
	self.drivingShaft = {};
	self.drivingShaft.node = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.drivingShaft#index"));

    local wiperAnimRootNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.wiper#rootNode"));
    self.wiperAnimCharSet = 0;
    if wiperAnimRootNode ~= nil and wiperAnimRootNode ~= 0 then
        self.wiperAnimCharSet = getAnimCharacterSet(wiperAnimRootNode);
        if self.wiperAnimCharSet ~= 0 then
            local clip = getAnimClipIndex(self.wiperAnimCharSet, getXMLString(xmlFile, "vehicle.wiper#clip"));
            assignAnimTrackClip(self.wiperAnimCharSet, 0, clip);
            setAnimTrackLoopState(self.wiperAnimCharSet, 0, true);
            local wiperAnimSpeedScale = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.wiper#speedScale"), 1);
			setAnimTrackSpeedScale(self.wiperAnimCharSet, 0, wiperAnimSpeedScale);
            self.wiperAnimDuration = getAnimClipDuration(self.wiperAnimCharSet, clip);
        end;
    end;
	self.isWiperActive = false;
	self.finishWiper = true;

	self.updateJoint = false;
	self.doLowering = false;
	self.loweringDone = false;
	self.nextAction = false;
	self.delay = 0;
end;

function DeutzIntrac:delete()
end;

function DeutzIntrac:mouseEvent(posX, posY, isDown, isUp, button)
end;

function DeutzIntrac:keyEvent(unicode, sym, modifier, isDown)
end;

function DeutzIntrac:update(dt)

	--used to get more updateIntervales then updateTick()
	if not self.startedUpdating then
		self.updateInterval = self.time+25;
		self.startedUpdating = true;
	end;

		for _, part in pairs(self.movingParts) do
			part.isDirty = true;
		end;

	if self:getIsActive() then
	--driving shaft
		if self.drivingShaft ~= nil then
			local x,y,z = getRotation(self.wheels[1].driveNode);
			setRotation(self.drivingShaft.node, 0 ,0, x*2);	
		end;
		Cylindered.updateMovingPart(self, self.movingParts[1]);	
		self.updateInterval = self.time+10;
	end;
end;

function DeutzIntrac:updateTick(dt)

	if self:getIsActive() then	
		if not self.finishWiper then
			if getAnimTrackTime(self.wiperAnimCharSet, 0) % self.wiperAnimDuration <= 100 then
				setAnimTrackTime(self.wiperAnimCharSet, 0, 0.0);
				disableAnimTrack(self.wiperAnimCharSet, 0);			
				self.finishWiper = true;
			end;
		end;

		if g_currentMission.environment.lastRainScale > 0.1 and g_currentMission.environment.timeSinceLastRain < 30 then
			if not self.isWiperActive then
				enableAnimTrack(self.wiperAnimCharSet, 0);
				self.isWiperActive = true;
			end;
		else
			if self.isWiperActive then
				self.isWiperActive = false;
				self.finishWiper = false;
			end;
		end;
	end;
end;

function DeutzIntrac:draw()	
	
end;

function DeutzIntrac:attachImplement(implement)

	local jointType = implement.object.attacherJoint.jointType;
	local jointIndex = implement.jointDescIndex;
	
	if jointType == Vehicle.JOINTTYPE_IMPLEMENT then
		if jointIndex == 1 then
			setVisibility(self.rearCoupling.node, false);
		end;
	elseif jointType == Vehicle.JOINTTYPE_TRAILER or jointType == Vehicle.JOINTTYPE_TRAILERLOW then	
		setVisibility(self.rearCoupling.trailerNode, jointType == Vehicle.JOINTTYPE_TRAILER);
		setVisibility(self.rearCoupling.trailerLowNode, not getVisibility(self.rearCoupling.trailerNode));
	end;
	self.updateJoint = true;
end;

function DeutzIntrac:detachImplement(implementIndex)
	local implement = self.attachedImplements[implementIndex];
	local jointIndex = implement.jointDescIndex;
	if jointIndex == 1 then
		setVisibility(self.rearCoupling.node, true);
	end;
end;

function DeutzIntrac:onLeave()
	if self.isWiperActive then
		disableAnimTrack(self.wiperAnimCharSet, 0);	
	end;
end;

function DeutzIntrac:onEnter()
	if self.isWiperActive then
		enableAnimTrack(self.wiperAnimCharSet, 0);	
	end;
end;